#! /usr/bin/python2

import numpy
from matplotlib import pyplot
from scipy.stats import norm

orig = [
    [
        (0.200000, (0.000000, 4.000000)),
        (0.500000, (-10.000000, 3.000000)),
        (0.300000, (5.000000, 5.000000)),
    ],
    [
        (0.100000, (0.000000, 3.000000)),
        (0.400000, (-8.000000, 3.000000)),
        (0.500000, (5.000000, 5.000000)),
    ],
    [
        (0.300000, (0.000000, 3.000000)),
        (0.300000, (-8.000000, 3.000000)),
        (0.400000, (5.000000, 5.000000)),
    ],
]

coem = [
    [
        (0.154980, (-0.245219, 2.822016)),
        (0.324151, (4.906791, 5.360373)),
        (0.520869, (-8.643671, 3.963201)),
    ],
    [
        (0.084005, (-0.245219, 2.822016)),
        (0.515311, (4.906791, 5.360373)),
        (0.400684, (-8.643671, 3.963201)),
    ],
    [
        (0.283541, (-0.245219, 2.822016)),
        (0.421456, (4.906791, 5.360373)),
        (0.295003, (-8.643671, 3.963201)),
    ],
]

def mixture_pdf(data, mix):
    components = [comp[0] * norm.pdf(data, comp[1][0], comp[1][1]) for comp in mix]
    return numpy.sum(components, 0)

def plot_mog(x, mix, components=False, color='r', ax=None, label=None):
    if ax is None:
        ax = pyplot.gca()
    
    if components:
        for comp in mix:
            ax.plot(x, comp[0] * norm.pdf(x, comp[1][0], comp[1][1]), color+":")
    
    ax.plot(x, mixture_pdf(x, mix), color, label=label)

if __name__ == "__main__":
    x = numpy.arange(-20, 20, 0.1)

    s = len(orig)

    f, axes = pyplot.subplots(nrows=s)

    for i in xrange(s):
        plot_mog(x, orig[i], components=True, color='r', label="Truth", ax=axes[i])
        plot_mog(x, coem[i], components=True, color='b', label="coEM", ax=axes[i])
        axes[i].set_ylim([0, 0.10])
        axes[i].legend()
    
    pyplot.show()
    
